The Rossiter-McLaughlin effect (Ohta et al. 2005)
===================================================

The Rossiter McLaughlin (RMcL) effect is an apparent RV shift of the stellar spectrum during
planetary transits. As the planet moves across the stellar disk, it eclipses different surface sections
with different radial velocities caused by stellar rotation. Here, we provide an implementation of the
analytical radial-velocity model presented by *Ohta et al. 2005* [#fOhta]_.

Contents:

.. toctree::
    
    rmcl.rst
    rmclExamples.rst

.. [#fOhta] Ohta et al. 2005, "The Rossiter-McLaughlin Effect and Analytic Radial
            Velocity Curves for Transiting Extrasolar Planetary Systems",
            2005ApJ...622.1118O
